## Computer Vision Pipeline Tools

[`cvpl_tools` documentation link](https://www.khanlab.ca/cvpl_tools/index.html)

A Python package with utilities on some use cases of file I/O, image processing and computer vision. Refer to the 
documentation link above for quickstarts, APIs, and introductions on various functionalities provided in this 
library.

### Dependency
This repository uses [Poetry](https://python-poetry.org/docs/) to manage dependency.